@@ -21,8 +21,12 @@
 #include "MediaInfo/MediaInfo_Config.h"
 #include "MediaInfo/File__Analyze.h"
 #include "MediaInfo/File__MultipleParsing.h"
-#include "ZenLib/Dir.h"
+#if defined(MEDIAINFO_FILE_YES)
 #include "ZenLib/File.h"
+#endif //defined(MEDIAINFO_DIRECTORY_YES)
+#if defined(MEDIAINFO_DIRECTORY_YES)
+#include "ZenLib/Dir.h"
+#endif //defined(MEDIAINFO_DIRECTORY_YES)
 #include "ZenLib/FileName.h"
 #if defined(MEDIAINFO_DIRECTORY_YES)
     #include "MediaInfo/Reader/Reader_Directory.h"
@@ -262,6 +266,8 @@ namespace MediaInfo_Debug_MediaInfo_Internal
 }
 using namespace MediaInfo_Debug_MediaInfo_Internal;
 
+Ztring File__Analyze_Encoded_Library_String(const Ztring &CompanyName, const Ztring &Name, const Ztring &Version, const Ztring &Date, const Ztring &Encoded_Library);
+
 //***************************************************************************
 // Constructor/destructor
 //***************************************************************************
@@ -363,6 +369,7 @@ size_t MediaInfo_Internal::Open(const String &File_Name_)
         return 0;
     }
     Config.File_Names_Pos=1;
+    Config.IsFinishing=false;
     }
 
     //Parsing
@@ -385,11 +392,8 @@ size_t MediaInfo_Internal::Open(const String &File_Name_)
 //---------------------------------------------------------------------------
 void MediaInfo_Internal::Entry()
 {
-    {
-    CriticalSectionLocker CSL(CS);
     MEDIAINFO_DEBUG_CONFIG_TEXT(Debug+=__T("Entry");)
     Config.State_Set(0);
-    }
 
     if ((Config.File_Names[0].size()>=6
         && Config.File_Names[0][0]==__T('m')
@@ -567,6 +571,7 @@ void MediaInfo_Internal::Entry()
                         }
                     }
 
+                    #if defined(MEDIAINFO_DIRECTORY_YES)
                     Ztring Name=Test.Name_Get();
                     Ztring BaseName=Name.SubString(Ztring(), __T("_"));
                     if (!BaseName.empty())
@@ -600,6 +605,7 @@ void MediaInfo_Internal::Entry()
                         for (size_t Pos=0; Pos<List.size(); Pos++)
                             Dxw+=" <clip file=\""+List[Pos].To_UTF8()+"\" />\r\n";
                     }
+                    #endif //defined(MEDIAINFO_DIRECTORY_YES)
 
                     if (!Dxw.empty())
                     {
@@ -653,10 +659,7 @@ void MediaInfo_Internal::Entry()
         }
     #endif //MEDIAINFO_FILE_YES
 
-    {
-    CriticalSectionLocker CSL(CS);
     Config.State_Set(1);
-    }
 }
 
 //---------------------------------------------------------------------------
@@ -804,6 +807,8 @@ size_t MediaInfo_Internal::Open_Buffer_SegmentChange ()
 {
     MEDIAINFO_DEBUG_CONFIG_TEXT(Debug+=__T("Open_Buffer_SegmentChange"))
 
+    if (Info == NULL)
+        return 0;
     Info->Open_Buffer_SegmentChange();
 
     return 1;
@@ -906,7 +911,7 @@ size_t MediaInfo_Internal::Open_Buffer_Seek (size_t Method, int64u Value, int64u
 {
     CriticalSectionLocker CSL(CS);
     if (Info==NULL)
-        return false;
+        return 0;
 
     return Info->Open_Buffer_Seek(Method, Value, ID);
 }
@@ -966,17 +971,17 @@ std::bitset<32> MediaInfo_Internal::Open_NextPacket ()
             else
         #endif //defined(MEDIAINFO_READER_NO)
             {
-                #if MEDIAINFO_NEXTPACKET
+                #if MEDIAINFO_DEMUX && MEDIAINFO_NEXTPACKET
                     Config.Demux_EventWasSent=false;
-                #endif //MEDIAINFO_NEXTPACKET
+                #endif //MEDIAINFO_DEMUX && MEDIAINFO_NEXTPACKET
                 Open_Buffer_Continue(NULL, 0);
-                #if MEDIAINFO_NEXTPACKET
+                #if MEDIAINFO_DEMUX && MEDIAINFO_NEXTPACKET
                     if (!Config.Demux_EventWasSent)
-                #endif //MEDIAINFO_NEXTPACKET
+                #endif //MEDIAINFO_DEMUX && MEDIAINFO_NEXTPACKET
                         Open_Buffer_Finalize();
-                #if MEDIAINFO_NEXTPACKET
+                #if MEDIAINFO_DEMUX && MEDIAINFO_NEXTPACKET
                     Demux_EventWasSent=Config.Demux_EventWasSent;
-                #endif //MEDIAINFO_NEXTPACKET
+                #endif //MEDIAINFO_DEMUX && MEDIAINFO_NEXTPACKET
             }
     }
 
@@ -1110,6 +1115,16 @@ Ztring MediaInfo_Internal::Get(stream_t StreamKind, size_t StreamPos, const Stri
         return Get(StreamKind, StreamPos, __T("Encoded_Application/String"), KindOfInfo, KindOfSearch);
     if (Parameter==__T("Encoded_Library") && Info && !Info->Retrieve(StreamKind, StreamPos, "Encoded_Library/String").empty())
         return Get(StreamKind, StreamPos, __T("Encoded_Library/String"), KindOfInfo, KindOfSearch);
+    if (Parameter==__T("Encoded_Library/String") && !MediaInfoLib::Config.ReadByHuman_Get())
+    {
+        //TODO: slight duplicate of content in Streams_Finish_HumanReadable_PerStream, should be refactorized
+        Ztring CompanyName=Get(StreamKind, StreamPos, __T("Encoded_Library_CompanyName"));
+        Ztring Name=Get(StreamKind, StreamPos, __T("Encoded_Library_Name"));
+        Ztring Version=Get(StreamKind, StreamPos, __T("Encoded_Library_Version"));
+        Ztring Date=Get(StreamKind, StreamPos, __T("Encoded_Library_Date"));
+        Ztring Encoded_Library=Get(StreamKind, StreamPos, __T("Encoded_Library"));
+        return File__Analyze_Encoded_Library_String(CompanyName, Name, Version, Date, Encoded_Library);
+    }
 
     CS.Enter();
     MEDIAINFO_DEBUG_CONFIG_TEXT(Debug+=__T("Get, StreamKind=");Debug+=Ztring::ToZtring((size_t)StreamKind);Debug+=__T(", StreamKind=");Debug+=Ztring::ToZtring(StreamPos);Debug+=__T(", Parameter=");Debug+=Ztring(Parameter);)
@@ -1131,15 +1146,17 @@ Ztring MediaInfo_Internal::Get(stream_t StreamKind, size_t StreamPos, const Stri
 
     //Special cases
     //-Inform for a stream
+#if defined(MEDIAINFO_TEXT_YES) || defined(MEDIAINFO_HTML_YES) || defined(MEDIAINFO_XML_YES) || defined(MEDIAINFO_CSV_YES) || defined(MEDIAINFO_CUSTOM_YES)
     if (Parameter==__T("Inform"))
     {
         CS.Leave();
-        Ztring InformZtring=Inform(StreamKind, StreamPos, true);
+        const Ztring InformZtring=Inform(StreamKind, StreamPos, true);
         CS.Enter();
         size_t Pos=MediaInfoLib::Config.Info_Get(StreamKind).Find(__T("Inform"));
         if (Pos!=Error)
             Stream[StreamKind][StreamPos](Pos)=InformZtring;
     }
+#endif
 
     //Case of specific info
     size_t ParameterI=MediaInfoLib::Config.Info_Get(StreamKind).Find(Parameter, KindOfSearch);
@@ -1263,8 +1280,10 @@ String MediaInfo_Internal::Option (const String &Option, const String &Value)
     else if (OptionLower.find(__T("file_seek"))==0)
     {
         #if MEDIAINFO_SEEK
-            if (Reader==NULL && Info==NULL)
-                return __T("Error: Reader pointer is empty");
+            #if !defined(MEDIAINFO_READER_NO)
+                if (Reader==NULL && Info==NULL)
+                    return __T("Error: Reader pointer is empty");
+            #endif //MEDIAINFO_READER_NO
 
             size_t Method=(size_t)-1;
             int64u SeekValue=(int64u)-1;
@@ -1322,10 +1341,12 @@ String MediaInfo_Internal::Option (const String &Option, const String &Value)
 
             CS.Leave();
             size_t Result;
-            if (Reader)
-                Result=Reader->Format_Test_PerParser_Seek(this, Method, SeekValue, ID);
-            else
-                Result=Open_Buffer_Seek(Method, SeekValue, ID);
+            #if !defined(MEDIAINFO_READER_NO)
+                if (Reader)
+                    Result=Reader->Format_Test_PerParser_Seek(this, Method, SeekValue, ID);
+                else
+            #endif //MEDIAINFO_READER_NO
+                    Result=Open_Buffer_Seek(Method, SeekValue, ID);
             CS.Enter();
             switch (Result)
             {
@@ -1397,17 +1418,18 @@ size_t MediaInfo_Internal::Count_Get (stream_t StreamKind, size_t StreamPos)
 //---------------------------------------------------------------------------
 size_t MediaInfo_Internal::State_Get ()
 {
-    CriticalSectionLocker CSL(CS);
     return (size_t)(Config.State_Get()*10000);
 }
 
 //---------------------------------------------------------------------------
+#if defined(MEDIAINFO_FILE_YES)
 void MediaInfo_Internal::TestContinuousFileNames ()
 {
     CriticalSectionLocker CSL(CS);
     if (Info)
         Info->TestContinuousFileNames();
 }
+#endif //defined(MEDIAINFO_FILE_YES)
 
 //---------------------------------------------------------------------------
 #if MEDIAINFO_EVENTS
